from enum import IntEnum


class SystemRole(IntEnum):
    R_ADM_START = 1
    R_ADM_CONFIG_SYSTEM = 2
    R_ADM_CONFIG_ARCHIVE = 3
    R_ADM_CONFIG_SECURITY = 4
    R_ADM_CONFIG_WMODULE = 5
    R_ADM_CONFIG_DMODULE = 6
    R_ADM_START_LICEDIT = 7
    R_ADM_START_AUTOACTION = 8
    R_ADM_EDIT_AUTOACTION = 9
    R_ADM_VIEW_PROTOCOLS = 10
    R_ASE_START_PROGRAM = 11
    R_ASE_EDIT_OBJDEF = 12
    R_ASE_REBUILD_DB = 13
    R_AAU_START_PROGRAM = 14
    R_AIX_START_PROGRAM = 15
    R_AIX_CONFIG_PROGRAM = 16
    R_CLNT_STORE_SETTINGS = 17
    R_DMS_SUPERVISOR = 18
    R_WFCLNT_USE = 19
    R_WFADM_START = 20
    R_WFEDIT_START = 21
    R_WFEDIT_ORG_EDIT = 22
    R_WFEDIT_MODEL_EDIT = 23
    R_WFIMP_START = 24
    R_WFTEST_START = 25
    R_WFSCRIPT_START = 26
    R_SRV_ADMIN = 27
    R_CLNT_OBJHIST = 28
    R_CLNT_EXPMOD = 29
    R_CLNT_EXPORT = 30
    R_CLNT_NOTES = 31
    R_CLNT_RESTORE_OBJECT = 32
    R_CLNT_TRAY = 33
    R_CLNT_EXTREQ_CFG = 34
    R_CLNT_SENDEXT = 35
    R_CLNT_START = 36
    R_CLNT_SYSTRAY = 37
    R_CLNT_EXTREQ_WORK = 38
    R_CLNT_ABO_ADMIN = 39
    R_CLNT_DELETETRAY = 40
    R_WEBEDIT_START = 41
    R_WEBEDIT_TRANSFER = 42
    R_WEBADM_START = 43
    R_CLNT_OBJINFO = 44
    R_CLNT_DEBUGEVENTS = 45
    R_CLNT_REL_SHOW = 46
    R_CLNT_VIS_CREATE = 47
    R_CLNT_VIS_ADMIN = 48
    R_CLNT_VIS_PUBLIC = 49
    R_ADM_CHG_OBJRIGHTS = 50
    R_CLNT_ARC_BAR = 51
    R_CLNT_ICON_BAR = 52
    R_CLNT_ARC_DELDOCS = 53
    R_ACTVERSYS_START = 54
    R_CLNT_REVISIT_ADMIN = 55
    R_CLNT_CFG_OBJHIST = 56
    R_CLNT_MULTI_MODIFICATION = 57
    R_WFEDIT_ATTENDANCE_EDIT = 58
    R_CLNT_ICON_ADD = 59
    R_CLNT_ICON_DEL = 60
    R_CLNT_WFPROXY = 61
    R_WFCLNT_ADMINISTRATE = 62
    R_CLNT_MOVE_OBJECTS = 63
    R_CLNT_ANN_EDIT = 64
    R_ADM_CONFIG_LOCALSECURITY = 65
    R_DMS_LOCALADM_EDIT = 66
    R_CLNT_WFROUTELIST = 67
    R_CLNT_WFPRIVATEROUTELIST = 68
    R_CLNT_WFPUBLICROUTELIST = 69
    R_WEBCLNT_START = 70
    R_CLNT_VIEWNOTES = 71
    R_SRV_SWITCH_CONTEXT = 72
    R_CLNT_VAR_SHOWALWAYS = 73
    R_CLNT_PRN_DOCS = 74
    R_CLNT_ARC_CHANGESTATE = 75
    R_CLNT_SHOW_MOBFAV = 76
    R_CLNT_ADJUST_RIBBONBAR = 77
    R_CLNT_EXECUTE_INQUIRY = 78
    R_CLNT_ACROSS_CABINET = 79
    R_CLNT_CONFIG_PROGRAMS = 80
    R_CLNT_VIEW_ANNOTATION = 81
    R_CLNT_ANNOTATION = 82
    R_CLNT_CREATE_REFERENCE = 83
    R_CLNT_CREATE_REFERENCE_DOCS = 84
    R_CLNT_SHARE_DOCS = 85
    R_CLNT_MANAGE_SHARED_DOCS = 86
    R_AIX_EDIT_PROGRAM = 87
    R_SRV_ADO_JOBS = 88
    R_CLNT_CLNTS = 89
    R_CLNT_WFVIEWPROXY = 90
    R_CLNT_REVISIT_FOROTHERS = 91
    R_CLNT_ABO_FOROTHERS = 92
    R_CLNT_PUBLICDESKTOP_ADMIN = 93
    R_CLNT_SCAN_DOCS = 94
    R_CLNT_SHOW_REGOBJCOUNT = 95
    R_ASE_DEF_VISIBILITIES = 96
    R_CLNT_EXPORT_INDEX_DATA = 97
    T_CLNT_REVERT_CHECKOUT = 98